@@ -4,9 +4,7 @@
  * Gnome Chemisty Utils
  * crystaldoc.h 
  *
- * Copyright (C) 2002-2004
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2004 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -34,6 +32,8 @@
 #include "crystalbond.h"
 #include "crystalline.h"
 #include "crystalcleavage.h"
+#include "document.h"
+#include <gcu/gldocument.h>
 
 namespace gcu
 {
@@ -78,13 +78,13 @@ enum gcLattices {cubic=0,
 /*!\class CrystalDoc gcu/crystaldoc.h
 The document containing the crystal structure.
 */				 
-class CrystalDoc
+class CrystalDoc: public GLDocument
 {
 public:
 /*!
 The constructor of CrystalDoc
 */
-	CrystalDoc ();
+	CrystalDoc (Application *App);
 /*!
 The destructor of CrystalDoc
 */
@@ -123,10 +123,6 @@ Draws the document using OpenGL primitives.
 */
 	void Draw ();
 /*!
-@return the largest distance from an object displayed in the document to the center of the model.
-*/
-	gdouble GetMaxDist () {return m_dDist;}
-/*!
 Creates a view of the document. This method should be overrided by programs deriving a new view class from
 CrystalView.
 
@@ -239,10 +235,6 @@ The maximum z coordinate in the representation of the crystal structure.
 */
 	gdouble m_zmax;
 /*!
-The maximum distance between an object and the center.
-*/
-	gdouble m_dDist; //maximum distance between an object and the center
-/*!
 true if cleavages must not change positions in the view.
 */
 	gboolean m_bFixedSize;  //true if cleavages must not change positions in the view
