@@ -4,7 +4,7 @@
  * Gnome Crystal
  * document.cc 
  *
- * Copyright (C) 2000-2006 Jean Brfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2000-2006 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -62,6 +62,7 @@
 #else
 #	include <sstream.h>
 #endif
+#include <glib/gi18n.h>
 
 #define SAVE	1
 #define LOAD	2
@@ -87,7 +88,7 @@ char *LatticeName[] = {"simple cubic",
 	"base-centered monoclinic",
 	"triclinic"};
 
-gcDocument::gcDocument (gcApplication *pApp) :CrystalDoc ()
+gcDocument::gcDocument (gcApplication *pApp) :CrystalDoc (pApp)
 {
 	Init ();
 	m_filename = NULL;
@@ -95,9 +96,6 @@ gcDocument::gcDocument (gcApplication *pApp) :CrystalDoc ()
 	m_bEmpty = true;
 	m_bDirty = false;
 	m_bClosing = false;
-	m_ps = NULL;
-	m_App = pApp;
-	m_App->AddDocument (this);
 }
 
 /*gcDocument::gcDocument(bool create_view)
@@ -124,19 +122,19 @@ void gcDocument::Define (unsigned nPage)
 {
 	switch(nPage) {
 	case 0:
-		new gcCellDlg (m_App, this);
+		new gcCellDlg (dynamic_cast <gcApplication *> (m_App), this);
 		break;
 	case 1:
-		new gcAtomsDlg (m_App, this);
+		new gcAtomsDlg (dynamic_cast <gcApplication *> (m_App), this);
 		break;
 	case 2:
-		new gcLinesDlg (m_App, this);
+		new gcLinesDlg (dynamic_cast <gcApplication *> (m_App), this);
 		break;
 	case 3:
-		new gcSizeDlg (m_App, this);
+		new gcSizeDlg (dynamic_cast <gcApplication *> (m_App), this);
 		break;
 	case 4:
-		new gcCleavagesDlg (m_App, this);
+		new gcCleavagesDlg (dynamic_cast <gcApplication *> (m_App), this);
 		break;
 	}
 }
@@ -195,24 +193,29 @@ void gcDocument::SetCell(gcLattices lattice, gdouble a, gdouble b, gdouble c, gd
 	m_gamma = gamma;
 }
 
-void gcDocument::SetFileName(const gchar* filename)
+void gcDocument::SetFileName (const string &filename)
 {
-	if (m_filename) g_free(m_filename);
-	m_filename = g_strdup(filename);
-	int i = strlen(filename) - 1;
-	while ((m_filename[i] != '/') && (i >= 0)) i--;
-	if (i >=0) 
-	{
-		m_filename[i] = 0;
-		chdir(m_filename);
+	if (m_filename)
+		g_free (m_filename);
+	m_filename = g_strdup (filename.c_str ());
+	char *dirname = g_path_get_dirname (m_filename);
+	m_App->SetCurDir (dirname);
+	g_free (dirname);
+	int i = filename.length () - 1;
+	while ((m_filename[i] != '/') && (i >= 0))
+		i--;
+	if (i >=0) {
+		m_filename [i] = 0;
+		chdir (m_filename);
 		m_filename[i] = '/';
 	}
 	i++;
-	int j = strlen(filename) - 1;
-	while ((i < j) && (m_filename[j] != '.')) j--;
-	gchar* title = (strcmp(m_filename + j, ".gcrystal"))? g_strdup(m_filename + i):g_strndup(m_filename + i, j - i);
-	SetTitle(title);
-	g_free(title);
+	int j = filename.length () - 1;
+	while ((i < j) && (m_filename[j] != '.'))
+		j--;
+	gchar* title = (strcmp (m_filename + j, ".gcrystal"))? g_strdup (m_filename + i):g_strndup (m_filename + i, j - i);
+	SetTitle (title);
+	g_free (title);
 }
 
 void gcDocument::SetTitle(const gchar* title)
@@ -236,7 +239,7 @@ void gcDocument::Save()
 
 	try {
 		xml = BuildXMLTree();
-	
+
 		if (xmlSaveFile (m_filename, xml) < 0)
 			Error (SAVE);
 			
@@ -273,7 +276,7 @@ void gcDocument::Error (int num)
 	g_free (mess);
 }
 
-bool gcDocument::Load (const gchar* filename)
+bool gcDocument::Load (const string &filename)
 {
 	xmlDocPtr xml = NULL;
 	gchar *oldfilename, *oldtitle;
@@ -284,7 +287,7 @@ bool gcDocument::Load (const gchar* filename)
 	try {
 		if (SetFileName (filename), !m_filename || !m_title)
 			throw (int) 0;
-		if (!(xml = xmlParseFile (filename)))
+		if (!(xml = xmlParseFile (filename.c_str ())))
 			throw (int) 1;
 		if (xml->children == NULL)
 			throw (int) 2;
@@ -417,7 +420,7 @@ void gcDocument::ParseXMLTree(xmlNode* xml)
 			}
 			else if (!strcmp( (gchar*) node->name, "view")) {
 				if (bViewLoaded) {
-					gcWindow *pWindow = new gcWindow (m_App, this);
+					gcWindow *pWindow = new gcWindow (dynamic_cast <gcApplication *> (m_App), this);
 					gcView *pView = pWindow->GetView ();
 					pView->LoadOld(node);
 				} else {
@@ -442,7 +445,7 @@ void gcDocument::OnNewDocument()
 typedef struct {int n; std::list<CrystalAtom*> l;} sAtom;
 typedef struct {int n; std::list<CrystalLine*> l;} sLine;
 
-void gcDocument::OnExportVRML(const gchar* FileName)
+void gcDocument::OnExportVRML (const string &FileName)
 {
 	char *old_num_locale, tmp[128];
 	double x0, x1, x2, x3, x4, x5;
@@ -454,7 +457,7 @@ void gcDocument::OnExportVRML(const gchar* FileName)
 		GnomeVFSResult res;
 		std::map<std::string, sAtom>AtomsMap;
 		std::map<std::string, sLine>LinesMap;
-		if ((res = gnome_vfs_create (&handle, FileName, GNOME_VFS_OPEN_WRITE, true, 0644)) != GNOME_VFS_OK)
+		if ((res = gnome_vfs_create (&handle, FileName.c_str (), GNOME_VFS_OPEN_WRITE, true, 0644)) != GNOME_VFS_OK)
 			throw (int) res;
 		old_num_locale = g_strdup(setlocale(LC_NUMERIC, NULL));
 		setlocale(LC_NUMERIC, "C");
@@ -573,12 +576,6 @@ gcView *gcDocument::GetNewView()
 	return NULL;
 }
 
-void gcDocument::SetDirty()
-{
-	m_bDirty = true;
-	if (m_ps) bonobo_persist_set_dirty(m_ps, m_bDirty);
-}
-
 void gcDocument::AddView(gcView* pView)
 {
 	m_Views.push_back(pView);
@@ -597,7 +594,7 @@ bool gcDocument::RemoveView (gcView* pView)
 		if (!VerifySaved ())
 			return false;
 	}
-	m_App->RemoveDocument (this);
+	dynamic_cast <gcApplication *> (m_App)->RemoveDocument (this);
 	delete this;
 	return true;
 }
@@ -675,14 +672,14 @@ const char* gcDocument::GetProgramId()
 	return "Gnome Crystal "VERSION;
 }
 
-void gcDocument::SaveAsImage (char const *filename, char const *type, map<string, string>& options)
+void gcDocument::SaveAsImage (const string &filename, char const *type, map<string, string>& options)
 {
-	m_pActiveView->SaveAsImage (filename, type, options);
+	m_pActiveView->SaveAsImage (filename, type, options, GetApp ()->GetImageResolution ());
 }
 
 bool gcDocument::LoadNewView (xmlNodePtr node)
 {
-	gcWindow *pWindow = new gcWindow (m_App, this);
+	gcWindow *pWindow = new gcWindow (dynamic_cast <gcApplication *> (m_App), this);
 	gcView *pView = pWindow->GetView ();
 	bool result = pView->Load (node);
 	if (!result)
