@@ -29,6 +29,7 @@
 #include "prefs.h"
 #include "view-settings.h"
 #include <gcu/crystalview.h>
+#include <glib/gi18n.h>
 
 //Callbacks
 static bool on_delete_event (GtkWidget* widget, GdkEvent *event, gcWindow* Win)
@@ -70,24 +71,14 @@ static void on_file_print (GtkWidget *widget, gcWindow* Win)
 	Win->GetApplication ()->OnFilePrint ();
 }
 
-static void on_export_jpeg (GtkWidget *widget, gcWindow* Win)
+static void on_file_save_as_image(GtkWidget* widget, gcWindow* Win)
 {
-	Win->GetApplication ()->OnExportJPEG ();
-}
-
-static void on_export_png (GtkWidget *widget, gcWindow* Win)
-{
-	Win->GetApplication ()->OnExportPNG ();
-}
-
-static void on_export_vrml (GtkWidget *widget, gcWindow* Win)
-{
-	Win->GetApplication ()->OnExportVRML ();
+	Win->GetApplication ()->OnSaveAsImage ();
 }
 
 static void on_view_new (GtkWidget *widget, gcWindow* Win)
 {
-	new gcWindow (Win->GetApplication (), Win->GetDocument ());
+	new gcWindow (Win->GetApplication (), Win->GetDoc ());
 }
 
 static void on_view_close (GtkWidget *widget, gcWindow* Win)
@@ -144,31 +135,31 @@ static void on_about (GtkWidget *widget, void *data)
 static void on_lattice(GtkWidget *widget, gcWindow *Win)
 {
 	if (Win)
-		Win->GetDocument ()->Define (0);
+		Win->GetDoc ()->Define (0);
 }
 
 static void on_atoms(GtkWidget *widget, gcWindow *Win)
 {
 	if (Win)
-		Win->GetDocument ()->Define (1);
+		Win->GetDoc ()->Define (1);
 }
 
 static void on_lines (GtkWidget *widget, gcWindow *Win)
 {
 	if (Win)
-		Win->GetDocument ()->Define (2);
+		Win->GetDoc ()->Define (2);
 }
 
 static void on_size (GtkWidget *widget, gcWindow *Win)
 {
 	if (Win)
-		Win->GetDocument ()->Define (3);
+		Win->GetDoc ()->Define (3);
 }
 
 static void on_cleavages (GtkWidget *widget, gcWindow *Win)
 {
 	if (Win)
-		Win->GetDocument ()->Define (4);
+		Win->GetDoc ()->Define (4);
 }
 
 static void on_view_settings (GtkWidget *widget, gcWindow *Win)
@@ -184,12 +175,12 @@ static void on_help (GtkWidget *widget, gcWindow* Win)
 
 static void on_web (GtkWidget *widget, gcWindow* Win)
 {
-	Win->GetApplication ()->OnWeb ();
+	Win->GetApp ()->OnWeb ();
 }
 
 static void on_mail (GtkWidget *widget, gcWindow* Win)
 {
-	Win->GetApplication ()->OnMail ();
+	Win->GetApp ()->OnMail ();
 }
 
 static void on_bug (GtkWidget *widget, gcWindow* Win)
@@ -199,9 +190,9 @@ static void on_bug (GtkWidget *widget, gcWindow* Win)
 
 static bool on_focus_in (GtkWidget *widget, GdkEventFocus *event, gcWindow* Win)
 {
-	gcApplication *App = Win->GetApplication ();
-	Win->GetDocument ()->SetActiveView (Win->GetView ());
-	App->SetActiveDocument (Win->GetDocument ());
+	gcApplication *App = Win->GetApp ();
+	Win->GetDoc ()->SetActiveView (Win->GetView ());
+	App->SetActiveDocument (Win->GetDoc ());
 	return false;
 }
 
@@ -244,6 +235,14 @@ static void on_disconnect_proxy (GtkUIManager *ui, GtkAction *action, GtkWidget
 	}
 }
 
+static void on_recent (GtkRecentChooser *widget, gcWindow *Win)
+{
+	gcApplication *App = Win->GetApp ();
+	GtkRecentInfo *info = gtk_recent_chooser_get_current_item (widget);
+	App->FileProcess (gtk_recent_info_get_uri (info), gtk_recent_info_get_mime_type (info), false, NULL, Win->GetDoc ());
+	gtk_recent_info_unref(info);
+}
+
 static GtkActionEntry entries[] = {
   { "FileMenu", NULL, N_("_File") },
 	  { "New", GTK_STOCK_NEW, N_("_New File"), NULL,
@@ -254,13 +253,8 @@ static GtkActionEntry entries[] = {
 		  N_("Save the current file"), G_CALLBACK (on_file_save) },
 	  { "SaveAs", GTK_STOCK_SAVE_AS, N_("Save _As..."), "<shift><control>S",
 		  N_("Save the current file with a different name"), G_CALLBACK (on_file_save_as) },
-	  { "ExportFileMenu", NULL, N_("_Export") },
-		{ "VRML", NULL, N_("VRML"), NULL,
-		  N_("Export to VRML"), G_CALLBACK (on_export_vrml) },
-		{ "PNG", NULL, N_("PNG"), NULL,
-		  N_("Export view to png file"), G_CALLBACK (on_export_png) },
-		{ "JPEG", NULL, N_("Jpeg"), NULL,
-		  N_("Export view to jpeg file"), G_CALLBACK (on_export_jpeg) },
+	  { "SaveAsImage", GTK_STOCK_SAVE_AS, N_("Save As _Image..."), "<control>I",
+		  N_("Save the current file as an image"), G_CALLBACK (on_file_save_as_image) },
 	  { "Print", GTK_STOCK_PRINT, N_("_Print..."), "<control>P",
 		  N_("Print the current file"), G_CALLBACK (on_file_print) },
 	  { "Close", GTK_STOCK_CLOSE, N_("_Close"), "<control>W",
@@ -289,7 +283,7 @@ static GtkActionEntry entries[] = {
 		  N_("Save all open files"), G_CALLBACK (on_save_all) },
 	  { "CloseAll", GTK_STOCK_CLOSE, N_("_Close All"), "<control>W",
 		  N_("Close all open files"), G_CALLBACK (on_close_all) },*/
-	  { "NewView", NULL, N_("Create new _windowl"), NULL,
+	  { "NewView", NULL, N_("Create new _window"), NULL,
 		  N_("Create a new window"), G_CALLBACK (on_view_new) },
 	  { "CloseView", NULL, N_("_Close this window"), NULL,
 		  N_("Close the current window"), G_CALLBACK (on_view_close) },
@@ -314,15 +308,10 @@ static const char *ui_description =
 "      <menuitem action='Open'/>"
 "      <menuitem action='Save'/>"
 "      <menuitem action='SaveAs'/>"
+"      <menuitem action='SaveAsImage'/>"
 "      <separator name='file-sep1'/>"
-"      <menu action='ExportFileMenu'>"
-"        <menuitem action='VRML'/>"
-"        <menuitem action='PNG'/>"
-"        <menuitem action='JPEG'/>"
-"      </menu>"
-"      <separator name='file-sep2'/>"
 "      <menuitem action='Print'/>"
-"      <separator name='file-sep3'/>"
+"      <separator name='file-sep2'/>"
 "      <menuitem action='Close'/>"
 "      <menuitem action='Quit'/>"
 "    </menu>"
@@ -356,8 +345,6 @@ static const char *ui_description =
 "    <toolitem action='Open'/>"
 "    <toolitem action='Save'/>"
 "    <toolitem action='Print'/>"
-"    <toolitem action='Close'/>"
-"    <toolitem action='Quit'/>"
 "  </toolbar>"
 "</ui>";
 
@@ -433,6 +420,17 @@ gcWindow::gcWindow (gcApplication *App, gcDocument *Doc)
 		g_error_free (error);
 	}
 
+	GtkWidget *menu = gtk_ui_manager_get_widget (m_UIManager, "/MainMenu/FileMenu/Open");
+	GtkWidget *w = gtk_recent_chooser_menu_new_for_manager (App->GetRecentManager ());
+	GtkRecentFilter *filter = gtk_recent_filter_new ();
+	gtk_recent_filter_add_mime_type (filter, "application/x-gcrystal");
+	gtk_recent_chooser_add_filter (GTK_RECENT_CHOOSER (w), filter);
+	g_signal_connect (G_OBJECT (w), "item-activated", G_CALLBACK (on_recent), this);
+	GtkWidget *item = gtk_menu_item_new_with_label (_("Open recent"));
+	gtk_menu_item_set_submenu (GTK_MENU_ITEM (item), w);
+	gtk_widget_show_all (item);
+	gtk_menu_shell_insert (GTK_MENU_SHELL (gtk_widget_get_parent (menu)), item, 3);
+
 	bar = gtk_ui_manager_get_widget (m_UIManager, "/MainMenu");
 	gtk_box_pack_start (GTK_BOX (vbox), bar, false, false, 0);
 	bar = gtk_ui_manager_get_widget (m_UIManager, "/MainToolbar");
@@ -444,7 +442,7 @@ gcWindow::gcWindow (gcApplication *App, gcDocument *Doc)
 		m_Doc->AddView (m_View);
 	}
 	m_View->SetWindow (this);
-	gtk_box_pack_start (GTK_BOX (vbox), m_View->CreateNewWidget (), true, true, 0);
+	gtk_box_pack_start (GTK_BOX (vbox), m_View->GetWidget (), true, true, 0);
 	m_Bar = gtk_statusbar_new ();
 	m_statusId = gtk_statusbar_get_context_id (GTK_STATUSBAR (m_Bar), "status");
 	gtk_statusbar_push (GTK_STATUSBAR (m_Bar), m_statusId, _("Ready"));
